@@ -536,10 +536,10 @@ int     bounce_header(VSTREAM *bounce, BOUNCE_INFO *bounce_info,
     /*
      * Trade confidentiality against availability.
      */
-#if 0
-    if (var_tls_required_enable)
+    if (var_tls_required_enable
+	&& (bounce_info->sendopts & SOPT_REQUIRETLS_ESMTP) == 0
+	&& (bounce_info->sendopts & SOPT_REQUIRETLS_HEADER) != 0)
 	post_mail_fprintf(bounce, "TLS-Required: no");
-#endif
 
     /*
      * Auto-Submitted header, as per RFC 3834.
